@@ -4,13 +4,14 @@
 ///         sieving. It is used for printing and counting primes
 ///         and for computing the nth prime.
 ///
-/// Copyright (C) 2018 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2019 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
 ///
 
 #include <primesieve/PrimeSieve.hpp>
+#include <primesieve/ParallelSieve.hpp>
 #include <primesieve/pmath.hpp>
 #include <primesieve/PrintPrimes.hpp>
 #include <primesieve/PreSieve.hpp>
@@ -51,41 +52,27 @@ const array<SmallPrime, 8> smallPrimes
 
 namespace primesieve {
 
-PrimeSieve::PrimeSieve() :
-  start_(0),
-  stop_(0),
-  flags_(COUNT_PRIMES),
-  parent_(nullptr)
+PrimeSieve::PrimeSieve()
 {
   int sieveSize = get_sieve_size();
   setSieveSize(sieveSize);
-  reset();
 }
 
-/// ParallelSieve creates one PrimeSieve
-/// child object for each thread.
-///
-PrimeSieve::PrimeSieve(PrimeSieve* parent) :
-  sieveSize_(parent->sieveSize_),
+/// Used for multi-threading
+PrimeSieve::PrimeSieve(ParallelSieve* parent) :
   flags_(parent->flags_),
+  sieveSize_(parent->sieveSize_),
   parent_(parent)
 { }
 
-PrimeSieve::~PrimeSieve()
-{ }
+PrimeSieve::~PrimeSieve() = default;
 
 void PrimeSieve::reset()
 {
   counts_.fill(0);
-  seconds_ = 0.0;
-  toUpdate_ = 0;
-  processed_ = 0;
   percent_ = -1.0;
-}
-
-bool PrimeSieve::isParallelSieve() const
-{
-  return parent_ != nullptr;
+  seconds_ = 0.0;
+  sievedDistance_ = 0;
 }
 
 bool PrimeSieve::isFlag(int flag) const
@@ -99,14 +86,45 @@ bool PrimeSieve::isFlag(int first, int last) const
   return (flags_ & mask) != 0;
 }
 
-bool PrimeSieve::isCountPrimes()   const { return isFlag(COUNT_PRIMES); }
-bool PrimeSieve::isPrintPrimes()   const { return isFlag(PRINT_PRIMES); }
-bool PrimeSieve::isPrint()         const { return isFlag(PRINT_PRIMES, PRINT_SEXTUPLETS); }
-bool PrimeSieve::isCountkTuplets() const { return isFlag(COUNT_TWINS, COUNT_SEXTUPLETS); }
-bool PrimeSieve::isPrintkTuplets() const { return isFlag(PRINT_TWINS, PRINT_SEXTUPLETS); }
-bool PrimeSieve::isStatus()        const { return isFlag(PRINT_STATUS, CALCULATE_STATUS); }
-bool PrimeSieve::isCount(int i)    const { return isFlag(COUNT_PRIMES << i); }
-bool PrimeSieve::isPrint(int i)    const { return isFlag(PRINT_PRIMES << i); }
+bool PrimeSieve::isCountPrimes() const
+{
+  return isFlag(COUNT_PRIMES);
+}
+
+bool PrimeSieve::isPrintPrimes() const
+{
+  return isFlag(PRINT_PRIMES);
+}
+
+bool PrimeSieve::isPrint() const
+{
+  return isFlag(PRINT_PRIMES, PRINT_SEXTUPLETS);
+}
+
+bool PrimeSieve::isCountkTuplets() const
+{
+  return isFlag(COUNT_TWINS, COUNT_SEXTUPLETS);
+}
+
+bool PrimeSieve::isPrintkTuplets() const
+{
+  return isFlag(PRINT_TWINS, PRINT_SEXTUPLETS);
+}
+
+bool PrimeSieve::isStatus() const
+{
+  return isFlag(PRINT_STATUS, UPDATE_GUI_STATUS);
+}
+
+bool PrimeSieve::isCount(int i) const
+{
+  return isFlag(COUNT_PRIMES << i);
+}
+
+bool PrimeSieve::isPrint(int i) const
+{
+  return isFlag(PRINT_PRIMES << i);
+}
 
 uint64_t PrimeSieve::getStart() const
 {
@@ -120,7 +138,10 @@ uint64_t PrimeSieve::getStop() const
 
 uint64_t PrimeSieve::getDistance() const
 {
-  return stop_ - start_;
+  if (start_ <= stop_)
+    return stop_ - start_;
+  else
+    return 0;
 }
 
 uint64_t PrimeSieve::getCount(int i) const
@@ -148,11 +169,6 @@ PreSieve& PrimeSieve::getPreSieve()
   return preSieve_;
 }
 
-double PrimeSieve::getStatus() const
-{
-  return percent_;
-}
-
 void PrimeSieve::setFlags(int flags)
 {
   flags_ = flags;
@@ -163,6 +179,16 @@ void PrimeSieve::addFlags(int flags)
   flags_ |= flags;
 }
 
+void PrimeSieve::setStart(uint64_t start)
+{
+  start_ = start;
+}
+
+void PrimeSieve::setStop(uint64_t stop)
+{
+  stop_ = stop;
+}
+
 /// Set the size of the sieve array in KiB (kibibyte)
 void PrimeSieve::setSieveSize(int sieveSize)
 {
@@ -170,41 +196,40 @@ void PrimeSieve::setSieveSize(int sieveSize)
   sieveSize_ = floorPow2(sieveSize_);
 }
 
-/// Set a start number (lower bound) for sieving
-void PrimeSieve::setStart(uint64_t start)
+void PrimeSieve::setStatus(double percent)
 {
-  start_ = start;
-}
-
-/// Set a stop number (upper bound) for sieving
-void PrimeSieve::setStop(uint64_t stop)
-{
-  stop_ = stop;
-}
-
-/// Print status in percent to stdout.
-/// @processed:  Sum of recently processed segments
-///
-bool PrimeSieve::updateStatus(uint64_t processed, bool tryLock)
-{
-  if (isParallelSieve())
+  if (!parent_)
   {
-    toUpdate_ += processed;
-    if (parent_->updateStatus(toUpdate_, tryLock))
-      toUpdate_ = 0;
+    auto old = percent_;
+    percent_ = percent;
+    if (sharedMemory_)
+      sharedMemory_->percent = percent_;
+    if (isFlag(PRINT_STATUS))
+      printStatus(old, percent_);
   }
+}
+
+void PrimeSieve::updateStatus(uint64_t dist)
+{
+  if (parent_)
+  {
+    updateDistance_ += dist;
+    if (parent_->tryUpdateStatus(updateDistance_))
+      updateDistance_ = 0;
+  }
   else
   {
-    processed_ += processed;
+    sievedDistance_ += dist;
     double percent = 100;
     if (getDistance() > 0)
-      percent = processed_ * 100.0 / getDistance();
-    double old = percent_;
+      percent = sievedDistance_ * 100.0 / getDistance();
+    auto old = percent_;
     percent_ = min(percent, 100.0);
+    if (sharedMemory_)
+      sharedMemory_->percent = percent_;
     if (isFlag(PRINT_STATUS))
       printStatus(old, percent_);
   }
-  return true;
 }
 
 void PrimeSieve::printStatus(double old, double current)
@@ -214,7 +239,7 @@ void PrimeSieve::printStatus(double old, double current)
   {
     cout << '\r' << percent << '%' << flush;
     if (percent == 100)
-      cout << endl;
+      cout << '\n';
   }
 }
 
@@ -255,7 +280,7 @@ void PrimeSieve::sieve(uint64_t start, uint64_t stop, int flags)
 }
 
 /// Sieve the primes and prime k-tuplets (twin primes,
-/// prime triplets, ...) in [start, stop]
+/// prime triplets, ...) in [start, stop].
 ///
 void PrimeSieve::sieve()
 {
@@ -264,12 +289,8 @@ void PrimeSieve::sieve()
   if (start_ > stop_)
     return;
 
+  setStatus(0);
   auto t1 = chrono::system_clock::now();
-  int initStatus = 0;
-  int finishStatus = 10;
-
-  if (isStatus())
-    updateStatus(initStatus);
 
   if (start_ <= 5)
     processSmallPrimes();
@@ -283,9 +304,7 @@ void PrimeSieve::sieve()
   auto t2 = chrono::system_clock::now();
   chrono::duration<double> seconds = t2 - t1;
   seconds_ = seconds.count();
-
-  if (isStatus())
-    updateStatus(finishStatus, false);
+  setStatus(100);
 }
 
 } // namespace
